indexing

	description: "Class that covers the common POSIX and Windows %
	%current process related routines."
	usage: "Just inherit from this class."
	notes: "Most of the features of this class are available only if%
	%you really are a ABSTRACT_CURRENT_PROCESS, they cannot be applied to%
	%an instance of this class, this to protect against unintended effects."

	author: "Berend de Boer"
	date: "$Date: 2003/05/08 $"
	revision: "$Revision: #4 $"


deferred class

	ABSTRACT_CURRENT_PROCESS


inherit

	STDC_CURRENT_PROCESS

	ABSTRACT_PROCESS


feature -- process properties

	pid: INTEGER is
		do
			Result := abstract_getpid
		end

	is_pid_valid: BOOLEAN is
			-- current process' id is always valid
		do
			Result := True
		end


feature -- Every process also has standard file descriptors which might not be compatible with stdin/stdout/stderr (Windows)

	fd_stdin: ABSTRACT_FILE_DESCRIPTOR is
		deferred
		ensure
			fd_stdin_not_void: Result /= Void
			not_owner: not Result.is_owner
		end

	fd_stdout: ABSTRACT_FILE_DESCRIPTOR is
		deferred
		ensure
			fd_stdout_not_void: Result /= Void
			not_owner: not Result.is_owner
		end

	fd_stderr: ABSTRACT_FILE_DESCRIPTOR is
		deferred
		ensure
			fd_stderr_not_void: Result /= Void
			not_owner: not Result.is_owner
		end


feature {NONE} -- Various

	sleep (seconds: INTEGER) is
			-- Delays process execution
		require
			max_portable_value: seconds >= 0 and seconds <= 65535
		local
			unslept_seconds: INTEGER
		do
			unslept_seconds := abstract_sleep (seconds)
			-- unslept_seconds should be 0 or else we got a signal
		end


feature {NONE} -- Abstract API

	abstract_getpid: INTEGER is
		deferred
		end

	abstract_sleep (a_seconds: INTEGER): INTEGER is
		require
			a_seconds_not_negative: a_seconds >= 0
		deferred
		end


end
